/*
 * Remote Clip synchronized clipboard
 * Copyright (C) 1999-2001 Carnegie Mellon University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Homepage: http://www.cs.cmu.edu/~rcm/lapis/
 */

import java.io.*;
import java.awt.datatransfer.*;

public class ConstantTransferable implements Transferable, Serializable {
    Object obj;

    public ConstantTransferable (Object obj) {
        this.obj = obj;
    }

    public ConstantTransferable (Transferable t) {
        try {
            try {
                obj = t.getTransferData (Flavors.filesFlavor);
                return;
            } catch (UnsupportedFlavorException e) {
            }
            
            try {
                obj = t.getTransferData (DataFlavor.stringFlavor);
                return;
            } catch (UnsupportedFlavorException e) {
            }
        } catch (IOException e) {
            Global.report (e);
        }

        obj = null;
    }

    public Object getTransferData (DataFlavor flavor) throws UnsupportedFlavorException, IOException {
        if (obj instanceof FileList) {
            if (flavor.equals (Flavors.filesFlavor))
                return obj;
        } else if (obj instanceof String) {
            if (flavor.equals (DataFlavor.stringFlavor))
                return (String)obj;
            else if (flavor.equals (DataFlavor.plainTextFlavor))
                return new StringReader ((String)obj);
        }
        
        throw new UnsupportedFlavorException (flavor);
    }

    public DataFlavor[] getTransferDataFlavors () {
        return
            (obj instanceof FileList)
            ? Flavors.FILES_FLAVORS
            : ((obj instanceof String)
               ? Flavors.STRING_FLAVORS
               : Flavors.NO_FLAVORS);
    }

    public boolean isDataFlavorSupported (DataFlavor flavor) {
        return Flavors.isDataFlavorSupported (flavor, 
                                              getTransferDataFlavors ());
    }
}
