/*
 * Remote Clip synchronized clipboard
 * Copyright (C) 1999-2001 Carnegie Mellon University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Homepage: http://www.cs.cmu.edu/~rcm/lapis/
 */

import java.awt.datatransfer.*;

public abstract class Flavors {

    public static final String UNKNOWN_TYPE = "application/x-unknown";
    public static final DataFlavor[] NO_FLAVORS = { };

    public static final String STRING_TYPE = "text/plain";
    public static final DataFlavor[] STRING_FLAVORS = {
        DataFlavor.stringFlavor,
        DataFlavor.plainTextFlavor,
    };

    public static final String FILES_TYPE = "application/x-filenames";
    public static final DataFlavor filesFlavor = 
        new DataFlavor (FILES_TYPE, "files");
    public static final DataFlavor[] FILES_FLAVORS = {
        filesFlavor
    };


    public static boolean areEqual (DataFlavor[] f1, DataFlavor[] f2) {
        if (f1 == f2)
            return true;
        if (f1.length != f2.length)
            return false;
        for (int i = 0; i < f1.length; ++i)
            if (!f1[i].equals (f2[i]))
                return false;
        return true;
    }

    public static boolean isDataFlavorSupported (DataFlavor flavor,
                                                 DataFlavor[] flavors) {
        for (int i = 0; i < flavors.length; ++i)
            if (flavor.equals (flavors[i]))
                return true;
        return false;
    }

    public static String getName (DataFlavor[] flavors) {
        if (flavors == STRING_FLAVORS)
            return "text";
        else if (flavors == FILES_FLAVORS)
            return "files";
        else if (isDataFlavorSupported (DataFlavor.stringFlavor, flavors))
            return "text";
        else
            return "unknown object";
    }

    public static String toMimeType (DataFlavor flavor) {
        if (DataFlavor.plainTextFlavor.equals (flavor)
            || DataFlavor.stringFlavor.equals (flavor))
            return STRING_TYPE;
        else if (filesFlavor.equals (flavor))
            return FILES_TYPE;
        else
            return UNKNOWN_TYPE;
    }

    public static String toMimeType (DataFlavor[] flavors) {
        // First check for known combinations
        if (flavors == STRING_FLAVORS)
            return STRING_TYPE;
        if (flavors == FILES_FLAVORS)
            return FILES_TYPE;

        // Then search for plaintext or string
        for (int i = 0; i < flavors.length; ++i)
            if (DataFlavor.plainTextFlavor.equals (flavors[i])
                || DataFlavor.stringFlavor.equals (flavors[i]))
                return STRING_TYPE;
        
        return UNKNOWN_TYPE;
    }

    public static String getMimeType (Transferable t) {
        return toMimeType (t.getTransferDataFlavors ());
    }

    public static DataFlavor[] toDataFlavors (String mimeType) {
        if (mimeType.equals (STRING_TYPE))
            return STRING_FLAVORS;
        else if (mimeType.equals (FILES_TYPE))
            return FILES_FLAVORS;
        else
            return NO_FLAVORS;
    }

    public static DataFlavor toDataFlavor (String mimeType) {
        if (mimeType.equals (STRING_TYPE))
            return DataFlavor.stringFlavor;
        else if (mimeType.equals (FILES_TYPE))
            return filesFlavor;
        else
            return DataFlavor.stringFlavor;
    }
}
