/*
 * Remote Clip synchronized clipboard
 * Copyright (C) 1999-2001 Carnegie Mellon University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Homepage: http://www.cs.cmu.edu/~rcm/lapis/
 */

import java.io.*;
import java.net.*;
import java.util.*;
import rcm.util.*;

public abstract class Global {


    //
    // Configuration
    //
    static Config config = new Config (".rclip");

    public static Config getConfig () {
        return config;
    }

    //
    // Debugging
    //
    static Debug debugObject = Debug.QUIET;

    public static Debug getDebug () {
        return debugObject;
    }

    public static void setDebug (Debug dbg) {
        debugObject = dbg;
    }
        
    public static void debug (Object obj) {
        debugObject.println (obj);
    }

    public static void debug (String str) {
        debugObject.println (str);
    }

    public static void report (Throwable t) {
        debugObject.report (t);
    }

    //
    // User interface
    //

    static UI ui;

    public static UI getUI () {
        if (ui == null)
            ui = new TTYUI ();
        return ui;
    }

    public static void setUI (UI ui) {
        Global.ui = ui;
    }

    public static void reportStatus (String message) {
        ui.reportStatus (message);
    }

    public static void popupError (String message) {
        ui.popupError (message);
    }


    //
    // Local hostname and port
    //

    // default hostname is localhost if not specified
    static InetAddress localHost;
    static {
        try {
            localHost = InetAddress.getLocalHost ();
            Global.debug ("localhost is " + localHost);
        } catch (UnknownHostException e) {
            Global.report (e);
        }
    }

    static int localPort
        = Integer.parseInt (Global.getConfig ().getProperty 
                            ("Port", 
                             String.valueOf (Locator.DEFAULT_PORT)));
        

    public static InetAddress getLocalHost () {
        return localHost;
    }

    public static void setLocalHost (InetAddress host) {
        localHost = host;
    } 

    public static void setLocalHost (String hostname) throws UnknownHostException {
        localHost = InetAddress.getByName (hostname);
    } 

    public static boolean isLocalHost (InetAddress addr) {
        return addr.getHostAddress ().equals ("127.0.0.1")
            || addr.equals (Global.getLocalHost ());
    }
    

    public static int getLocalPort () {
        return localPort;
    }

    public static void setLocalPort (int port) {
        localPort = port;
    } 


    //
    // Home directory
    //
    
    public static File getHomeDirectory () {
        return Config.getHomeDirectory ();
    }


    //
    // Version
    //

    public static final String VERSION = "3.0";

}
