/*
 * Remote Clip synchronized clipboard
 * Copyright (C) 1999-2001 Carnegie Mellon University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Homepage: http://www.cs.cmu.edu/~rcm/lapis/
 */

import java.awt.datatransfer.*;
import java.awt.*;
import java.awt.event.*;

public class OldXClipboard extends JavaClipboard {
    public OldXClipboard () {
    }
    
    //
    // To fix a bug with Java under X, we need to override 
    // JavaClipboard's ClipboardOwner implementation so that
    // we seize the clipboard and convert it to a nice 
    // StringSelection anytime another application changes it.
    //
    // The major drawback is that X applications that put rich text
    // (e.g. HTML) on the clipboard seriously lose, since this technique
    // instantly converts the clipboard to plain text.
    //
    public void reallyLostOwnership () {
        seizeSystemClipboard ();
        super.reallyLostOwnership ();
    }

    protected Transferable seizeSystemClipboard () {
        Global.debug ("seizing ownership of system clipboard");
        Clipboard systemClipboard = getSystemClipboard ();
        Transferable contents = systemClipboard.getContents (null);
        
        String str;
        try {
            str = (String) contents.getTransferData (DataFlavor.stringFlavor);
        } catch (Exception e) {
            Global.report (e);
            str = "";
        }
        contents = new StringSelection (str);

        try {
            acquiring = true;
            systemClipboard.setContents (contents, this);
        } finally {
            acquiring = false;
        }

        return contents;
    }

}
