/*
 * Remote Clip synchronized clipboard
 * Copyright (C) 1999-2001 Carnegie Mellon University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Homepage: http://www.cs.cmu.edu/~rcm/lapis/
 */

import java.io.*;
import java.net.*;
import java.util.*;
import java.util.zip.*;
import rcm.io.TempFile;
import rcm.progress.*;
import javax.net.ssl.*;
import com.sun.net.ssl.SSLContext;

public class SecureRemoteFileList extends RemoteFileList {
    
    public SecureRemoteFileList () {
    }

    public SecureRemoteFileList (FileList fl) throws IOException {
        super (fl);

    }

    //
    // creating sockets
    //

    protected Socket createSocket (String host,
                                   int port) throws IOException {
        SSLContext sslContext;
        try {
            sslContext = makeSSLContext ();
        } catch (Exception e) {
            throw new IOException (e.toString ());
        }

        SSLSocket socket = (SSLSocket)
            sslContext
            .getSocketFactory ()
            .createSocket(host, port);

        socket.setNeedClientAuth (true);

        Global.debug ("starting handshake");
        socket.startHandshake ();
        Global.debug ("handshake complete");
        
        SSLSession session = socket.getSession ();
        Global.debug ("cipher suite = " + session.getCipherSuite ());
        
        return socket;
    }
            
    protected ServerSocket createServerSocket (int port) throws IOException { 
        SSLContext sslContext;
        try {
            sslContext = makeSSLContext ();
        } catch (Exception e) {
            throw new IOException (e.toString ());
        }

        SSLServerSocket socket = (SSLServerSocket)
            sslContext
            .getServerSocketFactory ()
            .createServerSocket (port);

        socket.setNeedClientAuth (true);

        return socket;
    }

    protected SSLContext makeSSLContext () throws Exception { 
        return ((SSLEncryption) Encryption.getInstance ())
            .makeSSLContext (true);
    }
            

}

