package rcm.win32;

import java.awt.*;
import java.awt.event.*;

public class TrayIcon extends Component {
    private int internal;
    private boolean visible;
    private String tooltip;

    static boolean supported;
    static {
        supported = (System.getProperty ("os.name").startsWith ("Windows"));

        if (supported) {
            try {
                System.loadLibrary ("TrayIcon");
            } catch (Throwable t) {
                t.printStackTrace ();
                supported = false;
            }
        }
    }

    public TrayIcon () throws UnsupportedPlatformException {
        if (!supported)
            throw new UnsupportedPlatformException ();
        create ();
    }
        
    public TrayIcon (String tooltip) throws UnsupportedPlatformException {
        this ();
        setTooltip (tooltip);
    }

    public void dispose () {
        setVisible (false);
        destroy ();
    }

    public void setVisible (boolean visible) {
        if (visible != this.visible) {
            this.visible = visible;
            changeVisibility ();
        }
    }

    public boolean isVisible () {
        return visible;
    }

    public void setTooltip (String tooltip) {
        if (tooltip != this.tooltip) {
            this.tooltip = tooltip;
            changeTooltip ();
        }
    }

    public String getTooltip () {
        return tooltip;
    }


    //
    // native interface
    //

    private native void create ();
    private native void destroy ();
    private native void changeVisibility ();
    private native void changeTooltip ();

    private void internalMouseClicked (boolean right, boolean doubleClick, 
                                       int x, int y){
        try {
            MouseEvent evt = 
                new MouseEvent (this, 
                                MouseEvent.MOUSE_CLICKED,
                                System.currentTimeMillis (),
                                right 
                                ? MouseEvent.BUTTON2_MASK
                                : MouseEvent.BUTTON1_MASK, 
                                x, y,
                                doubleClick ? 2 : 1,
                                right);
            EventQueue queue =
                Toolkit.getDefaultToolkit ().getSystemEventQueue ();

            queue.postEvent (evt);

        } catch (Throwable t) {
            t.printStackTrace ();
        }
    }

    //
    // testing
    //

    public static void main (String[] args) throws Exception {
        TrayIcon trayIcon = new TrayIcon ();
        trayIcon.addMouseListener (new MouseAdapter () {
                public void mouseClicked (MouseEvent evt) {
                    System.out.println ("clicked " + evt);
                }
            });
        pause ("created icon");

        trayIcon.setVisible (true);
        pause ("showed icon");

        trayIcon.setVisible (false);
        pause ("hid icon");

        trayIcon.setVisible (true);
        pause ("showed icon again");

        for (int i = 0; i < args.length; ++i) {
            trayIcon.setTooltip (args[i]);
            pause ("tooltip = " + args[i]);
        }

        trayIcon.setTooltip (null);
        pause ("set tooltip to null");

        trayIcon.dispose ();
        pause ("destroyed icon");

        System.exit (0);
    }

    static void pause (String msg) throws Exception {
        System.out.println (msg + ", press return");
        System.in.read ();
    }
}
